OpenTAXII
=========

TAXII server implementation in Python from `EclecticIQ <https://www.eclecticiq.com/>`_.

OpenTAXII is a robust Python implementation of TAXII Services that 
delivers rich feature set and friendly pythonic API built on top of 
well designed application.

OpenTAXII is guaranteed to be compatible with `Cabby <http://pypi.python.org/pypi/cabby>`_, TAXII client library.

:Source: https://github.com/EclecticIQ/OpenTAXII
:Documentation: http://opentaxii.readthedocs.org
:Information: https://www.eclecticiq.com
:Download: https://pypi.python.org/pypi/opentaxii/

|travis badge| |landscape.io badge| |coveralls.io badge| |version badge| |py.version badge| |downloads badge| |license badge| |docs badge|

.. |travis badge| image:: https://travis-ci.org/EclecticIQ/OpenTAXII.svg?branch=master
   :target: https://travis-ci.org/EclecticIQ/OpenTAXII
   :alt: Build Status
.. |landscape.io badge| image:: https://landscape.io/github/EclecticIQ/OpenTAXII/master/landscape.svg?style=flat
   :target: https://landscape.io/github/EclecticIQ/OpenTAXII/master
   :alt: Code Health
.. |coveralls.io badge| image:: https://coveralls.io/repos/EclecticIQ/OpenTAXII/badge.svg
   :target: https://coveralls.io/r/EclecticIQ/OpenTAXII
   :alt: Coverage Status
.. |version badge| image:: https://pypip.in/version/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/ 
.. |py.version badge| image:: https://pypip.in/py_versions/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/ 
.. |downloads badge| image:: https://pypip.in/download/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/
.. |license badge| image:: https://pypip.in/license/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/
.. |docs badge| image:: https://readthedocs.org/projects/opentaxii/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/opentaxii/

Getting started
---------------
See `the documentation <https://opentaxii.readthedocs.org/en/latest/installation.html>`_.

Feedback
--------
You are encouraged to provide feedback by commenting on open issues or sending us 
email at opentaxii@eclecticiq.com
